/*
 *  This script needs to send lead when client click on whatsApp icon in Elementor Widget
 */


/*
 *  Object to work with temporary data which are kept in the browser local storage
 */
var FixdigitalWhatsAppElementorWidgetLocalStorage = {

    get: function(param) {
        if (!window.localStorage) return null;

        var value = null;
        var now =  (new Date()).getTime();
        var data = JSON.parse( window.localStorage.getItem(param) );

        if (jQuery.isPlainObject(data)) {
            if (data.expires > now) {
                value = data.value;
            } else {
                window.localStorage.removeItem(param);
            }
        }

        return value;
    },


    set: function(param, value, lifeInDays) {
        if (!window.localStorage) return;

        var now = new Date();
        var expires = now.getTime() + (lifeInDays * 24*60*60*1000) ;

        var data = {
            value : value,
            expires : expires
        };

        window.localStorage.setItem(param, JSON.stringify(data));
    }


};



/*
 *   Utils
 *
 */
var FixdigitalWhatsAppElementorWidgetUtils = {
    getViewId: function(projectId, projectTypeId){
        var viewId = [
            '0_0',
            projectId,
            projectTypeId,
            this.toDateFormatString(),
            this.guid()
        ].join('_');
        return viewId;
    },


    guid: function(){
        function s4() {
          return Math.floor((1 + Math.random()) * 0x10000)
            .toString(16)
            .substring(1);
        }

        return `${ s4() }${ s4() }-${ s4() }-${ s4() }-${ s4() }-${ s4() }${ s4() }${ s4() }`;
    },


    toDateFormatString: function(){
        var date = new Date();
        var month = (date.getMonth() + 1).toString();
        month = month.length === 1 ? '0'+month : month;
        var day = date.getDate().toString();
        day = day.length === 1 ? '0'+day : day;
        var hours = date.getHours() < 10 ? ('0'+date.getHours()) : date.getHours().toString();
        var mins = date.getMinutes() < 10 ? ('0'+date.getMinutes()) : date.getMinutes().toString();
        var secs = date.getSeconds() < 10 ? ('0'+date.getSeconds()) : date.getSeconds().toString();
        return `${ date.getFullYear() }-${ month }-${ day }-${ hours }-${ mins }-${ secs }`;
    },


    /*
     *  Try to get param from cookie at first, if it not found then try to get it from localStorage.
     */
    readTempParam: function(name) {
        var val = this.readCookie(name);

        if (val === null) {
            val = FixdigitalWhatsAppElementorWidgetLocalStorage.get(name);
        }

        return val;
    },


    readCookie: function(name) {
        var nameEQ = name + "=";
        var ca = document.cookie.split(';');
        for(var i=0;i < ca.length;i++) {
            var c = ca[i];
            while (c.charAt(0)==' ') c = c.substring(1,c.length);
            if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
        }
        return null;
    },


    saveTempParam: function(name, value, days) {
        this.createCookie(name, value, days);
        FixdigitalWhatsAppElementorWidgetLocalStorage.set(name, value, days);
    },


    createCookie: function(name, value, days) {
        value = value ? value : '';
        var expires = "";

        if (days) {
            var date = new Date();
            date.setTime(date.getTime()+(days*24*60*60*1000));
            expires = "; expires="+date.toGMTString();
        }
        document.cookie = name+"="+value+expires+"; path=/";
    },


    eraseCookie: function(name) {
        this.saveTempParam(name,"",-1);
    },


    getOriginalChannelIdFromUrl: function() {
        var $ = jQuery;
        var channelId = null;
        var channelIdRegex = /[?#&]{1}channelID=(-?[\d]+)/ig;
        var result;
        var allResults = [];
        var allChannelIds = [];
        var i;

        // at first try to get all channelID params from query string
        result = (location.search).match(channelIdRegex);
        if ($.isArray(result)) {
            for (i=0; i<result.length; i++) {
                allResults.push( result[i] );
            }
        }

        // at second try to get all channelID params from hash
        result = (location.hash).match(channelIdRegex);
        if ($.isArray(result)) {
            for (i=0; i<result.length; i++) {
                allResults.push( result[i] );
            }
        }

        // get values of the selected channelID params
        for (i=0; i<allResults.length; i++) {
            result = (allResults[i]).match( /-?[\d]+$/i );
            if ($.isArray(result) && result.length) {
                if (result[0]) {
                    allChannelIds.push( result[0] );
                }
            }
        }

        // get last channelID from the found ones
        if (allChannelIds.length) {
            channelId = allChannelIds[ (allChannelIds.length - 1) ];
        }

        return channelId;
    },




    findChannelId : function(){
        var channelId = this.getOriginalChannelIdFromUrl();

        if (!channelId) {
            channelId = jQuery.trim( this.readTempParam( 'fixdigital-origin_channelid' ) );
        }

        channelId = channelId ? channelId : null;

        return channelId;
    }
};




/*
 *  Prepare data and send it as lead to www.fixdigital.co.il
 */
jQuery(function(){
    var $ = jQuery;
    var utils = FixdigitalWhatsAppElementorWidgetUtils;
    var data = {
//        AssetId: 3757,
//        AssetTypeId: 4,
//        PageUrl: "https://fixdigitalcrm.com/he/crm/",
        ChannelId: utils.findChannelId(),
        PageUrl: window.location.href,
        Phone: null,
        UrlReferer: document.referrer,
        ViewId: null
    };

    if ($.isPlainObject(fixdigitalWhatsAppElementorPluginData)) {
        $.each(fixdigitalWhatsAppElementorPluginData, function(key, val){
            if ($.type(val) === "string" && $.isNumeric(val)) {
                fixdigitalWhatsAppElementorPluginData[key] = parseInt(val);
            }
        });

        $.extend(data, fixdigitalWhatsAppElementorPluginData);
    }


    var $whatsAppLinks = $('.fixWhatsAppElement a[data-wa_number]');
    $whatsAppLinks.click(function(){
        var $link = $(this);

        data.Phone    = $link.attr('data-wa_number');
        data.TenantID = $link.attr('data-tenant_id');
        data.ClientID = $link.attr('data-client_id');
        data.Message  = $link.attr('data-wa_message');

        // global variable: window.fxd_viewid should be initialized previously by the plugin: 'fixdigital-integration', if it is installed
        data.ViewId = window.fxd_viewid || utils.getViewId(data.projectID, data.projectTypeID);

        // send lead about whatsapp
        $.ajax({
            url: "https://www.fixdigital.co.il/api/forms/whatsappview",
            type: 'POST',
            data: JSON.stringify(data),
            dataType: 'json',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            }
        }).done(function() {
            console.log( "'whatsappview': ajax request success" , data );
        }).fail(function() {
            console.log( "'whatsappview':ajax request fail" );
        }).always(function() {
            console.log( "'whatsappview':ajax request is competed" );
        });

    });

});

