<?php
namespace FixWhatsAppElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Icon_Box;

use Elementor\Scheme_Color;

use Elementor\Core\Kits\Documents\Tabs\Global_Colors;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

abstract class FixWhatsApp extends Widget_Icon_Box {

	public function get_name() {
		return 'fix-whatsapp';
	}

	public function get_title() {
		return __( 'FixDigital WhatsApp', 'fix-whatsapp-elementor' );
	}

	public function get_icon() {
		return $this->_getIcon('whatsapp');
	}

	public function get_categories() {
		return [ 'other-elements' ];
	}


    /*
     *  This method is used in version children: FixWhatsApp_*
     */
    protected function _addRegisterControls()
    {
		$this->start_controls_section(
			'section_icon',
			[
				'label' => __( 'FixDigital WhatsApp', 'elementor' ),
			]
		);


		$this->add_control(
			'icon',
			[
				'label' => __( 'Choose Icon', 'elementor' ),
				'type' => Controls_Manager::ICON,
                'fa4compatibility' => '',
                'include' => [
                    'fab fa-whatsapp',
                ],
				'default' => 'fab fa-whatsapp',
			]
		);


		$this->add_control(
			'whatsapp_number',
			[
				'label' => __( 'WhatsApp number (only digitals)', 'fix-whatsapp-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
                'input_type' => 'number',
			]
		);



        $this->add_control(
			'whatsapp_message',
			[
				'label' => __( 'WhatsApp message', 'fix-whatsapp-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				// 'label_block' => true,
                // 'input_type' => 'number',
			]
		);


        $this->add_control(
			'tenanat_id',
			[
				'label' => __( 'Tenant ID', 'fix-whatsapp-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
                'input_type' => 'number',
			]
		);


        $this->add_control(
			'client_id',
			[
				'label' => __( 'Client ID', 'fix-whatsapp-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
                'input_type' => 'number',
			]
		);


		$this->add_control(
			'position',
			[
				'label' => __( 'Icon Position', 'elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'default' => 'right',
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => $this->_getIcon('align-left'),
					],
					'center' => [
						'title' => __( 'center', 'elementor' ),
						'icon' => $this->_getIcon('align-center'),
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => $this->_getIcon('align-right'),
					],
				],
				'prefix_class' => 'elementor-position-',
				'toggle' => false,
                'selectors' => [
					'{{WRAPPER}} .fixWhatsAppElement' => 'text-align: {{VALUE}}',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => __( 'Icon', 'elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'primary_color',
			$this->_getPrimaryColorData()
		);


		$this->add_responsive_control(
			'icon_space',
			[
				'label' => __( 'Spacing', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}}.elementor-position-right .elementor-icon-box-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}}.elementor-position-left .elementor-icon-box-icon' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Size', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 6,
						'max' => 300,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_hover',
			[
				'label' => __( 'Icon Hover', 'elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'hover_primary_color',
			$this->_getPrimaryHoverColorData()
		);


		$this->add_control(
			'hover_animation',
			[
				'label' => __( 'Animation', 'elementor' ),
				'type' => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$this->end_controls_section();

	}




    protected function render() {
        $uniqId = uniqid('fixWhatsAppElement-');

		$settings = $this->get_settings();

		$this->add_render_attribute( 'icon', 'class', [
            'elementor-icon',
            'elementor-animation-' . $settings['hover_animation']
        ]);

		$icon_attributes = $this->get_render_attribute_string( 'icon' );
        $whatsAppMsg = urlencode($settings['whatsapp_message']);
        $whatsAppUrl = "https://wa.me/" . $settings['whatsapp_number'] . "?text=$whatsAppMsg";
		?>

        <div id="<?= $uniqId ?>" class="elementor-icon-box-wrapper fixWhatsAppElement">
            <div class="elementor-icon-box-icon">
                <a <?php echo $icon_attributes; ?>
                        href="<?php echo $whatsAppUrl; ?>"
                        target="_blank"
                        data-wa_number="<?php echo $settings['whatsapp_number']; ?>"
                        data-wa_message="<?php echo $whatsAppMsg ?>"
                        data-tenant_id="<?php echo $settings['tenanat_id']; ?>"
                        data-client_id="<?php echo $settings['client_id']; ?>" >

                    <i class="<?php echo $settings['icon'] ?>" data-u="alreadySavedElement"></i>
                </a>
            </div>
        </div>

        <?php

	}



    private function _getPrimaryColorData()
    {
        if ( version_compare( ELEMENTOR_VERSION, '3.6.0', '>=' ) ) {
            $data = [
                'label' => esc_html__( 'Primary Color', 'elementor' ),
                'type' => Controls_Manager::COLOR,
                'global' => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
                'default' => '#1fb141',
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon, {{WRAPPER}} .elementor-icon' => 'fill: {{VALUE}}; color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ];

        } else {
            $data = [
                'label' => __( 'Primary Color', 'elementor' ),
                'type' => Controls_Manager::COLOR,
                'scheme' => [
                    'type' => Scheme_Color::get_type(),
                    'value' => Scheme_Color::COLOR_1,
                ],
                'default' => '#1fb141',
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon, {{WRAPPER}}.elementor-icon' => 'color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ];
        }

        return $data;
    }




    private function _getPrimaryHoverColorData()
    {
		$data = [
			'label' => __( 'Primary Color', 'elementor' ),
			'type' => Controls_Manager::COLOR,
			'default' => '',
			'selectors' => [
				'{{WRAPPER}} .elementor-icon:hover' => 'color: {{VALUE}}; border-color: {{VALUE}};',
			],
		];

        if ( version_compare( ELEMENTOR_VERSION, '3.6.0', '>=' ) ) {
            $data['global'] = [
				'default' => Global_Colors::COLOR_PRIMARY,
			];

        } else {
            $data['scheme'] = [
				'type' => Scheme_Color::get_type(),
				'value' => Scheme_Color::COLOR_1,
			];
        }

        return $data;
    }




    private function _getIcon($name)
    {
        $iconsData = [
            'ellipsis-h'    => ['fa' => 'fa fa-ellipsis-h',    'eicon' => 'eicon-ellipsis-h'],
            'align-left'    => ['fa' => 'fa fa-align-left',    'eicon' => 'eicon-text-align-left'],
            'align-right'   => ['fa' => 'fa fa-align-right',   'eicon' => 'eicon-text-align-right'],
            'align-center'  => ['fa' => 'fa fa-align-center',  'eicon' => 'eicon-text-align-center'],
            'align-justify' => ['fa' => 'fa fa-align-justify', 'eicon' => 'eicon-text-align-justify'],
            'phone'         => ['fa' => 'fa fa-phone',         'eicon' => 'eicon-tel-field'],
            'whatsapp'      => ['fa' => 'fa fa-whatsapp',      'eicon' => 'fab fa-whatsapp'],
        ];

        if ( version_compare( ELEMENTOR_VERSION, '2.5.0', '>=' ) ) {
            $icon = isset($iconsData[$name]['eicon']) ? $iconsData[$name]['eicon'] : 'eicon-circle-o';

        } else {
            $icon = isset($iconsData[$name]['fa']) ? $iconsData[$name]['fa'] : 'fa fa-question';
        }

        return $icon;
    }



    protected function _createContentTemplate() {
        $uniqId = uniqid('fixWhatsAppElement-');

		?>
        <#
            var link = settings.whatsapp_number ? 'href="tel:' + settings.whatsapp_number + '"' : '';
			var iconTag = link ? 'a' : 'span';
            var displayVal = settings.show_content_on_mobile === 'yes' ? '' : 'none';
            console.log(settings.show_content_on_mobile);

            var icon = (typeof settings.icon === 'object' && settings.icon !== null && settings.icon.value) ? settings.icon.value : settings.icon;
        #>


        <div id="<?= $uniqId ?>" class="elementor-icon-box-wrapper fixWhatsAppElement">
            <div class="elementor-icon-box-icon">
                <a href="https://wa.me/{{ settings.whatsapp_number }}" class="elementor-icon elementor-animation-{{ settings.hover_animation }}" target="_blank">
                    <i class="{{ icon }}" data-u="justAddedElementInEditor"></i>
                </a>
            </div>
        </div>


		<?php
	}



}
